<?php
/**
 * exbico functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package exbico
 */

if ( ! defined( 'EXBICO_S_VERSION' ) ) {
	// Replace the version number of the theme on each release.
	define( 'EXBICO_S_VERSION', '1.0.1' );
}

if ( ! function_exists( 'exbico_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function exbico_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on exbico, use a find and replace
		 * to change 'exbico' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'exbico', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );
		
		// Image Size
		add_image_size('exbico-service-thumb', 150, 150, true);
		add_image_size('exbico-team-thumb', 255, 330, true);
		add_image_size('exbico-blog-thumb', 400, 480, true);
		add_image_size('exbico-blog-single-thumb', 670, 400, true);

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus(
			array(
				'menu-1' => esc_html__( 'Primary', 'exbico' ),
			)
		);

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support(
			'html5',
			array(
				'search-form',
				'comment-form',
				'comment-list',
				'gallery',
				'navigation-widgets',
				'caption',
				'style',
				'script',
			)
		);

		// Set up the WordPress core custom background feature.
		add_theme_support(
			'custom-background',
			apply_filters(
				'exbico_custom_background_args',
				array(
					'default-color' => 'ffffff',
					'default-image' => '',
				)
			)
		);

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support(
			'custom-logo',
			array(
				'height'      => 250,
				'width'       => 250,
				'flex-width'  => true,
				'flex-height' => true,
			)
		);
		
		/*
		* Enable support for wide alignment class for Gutenberg blocks.
		*/
		add_theme_support( 'align-wide' );

		// Add support for Block Styles.
		add_theme_support( 'wp-block-styles' );
		
		
	}
endif;
add_action( 'after_setup_theme', 'exbico_setup' );


/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function exbico_content_width() {
	// This variable is intended to be overruled from themes.
	// Open WPCS issue: {@link https://github.com/WordPress-Coding-Standards/WordPress-Coding-Standards/issues/1043}.
	// phpcs:ignore WordPress.NamingConventions.PrefixAllGlobals.NonPrefixedVariableFound
	$GLOBALS['content_width'] = apply_filters( 'content_width', 640 );
}
add_action( 'after_setup_theme', 'exbico_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function exbico_widgets_init() {
	register_sidebar(
		array(
			'name'          => esc_html__( 'Sidebar Main', 'exbico' ),
			'id'            => 'sidebar-1',
			'description'   => esc_html__( 'Add widgets here.', 'exbico' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		)
	);
	register_sidebar( array(
		'name'          => esc_html__( 'Footer Widget 1', 'exbico' ),
		'id'            => 'exbico_footer_1',
		'description'   => esc_html__( 'Add footer widget here.', 'exbico' ),
		'before_widget' => '<div id="%1$s" class="single-widget lists widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
	register_sidebar( array(
		'name'          => esc_html__( 'Footer Widget 2', 'exbico' ),
		'id'            => 'exbico_footer_2',
		'description'   => esc_html__( 'Add footer widget here.', 'exbico' ),
		'before_widget' => '<div id="%1$s" class="single-widget lists widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
	register_sidebar( array(
		'name'          => esc_html__( 'Footer Widget 3', 'exbico' ),
		'id'            => 'exbico_footer_3',
		'description'   => esc_html__( 'Add footer widget here.', 'exbico' ),
		'before_widget' => '<div id="%1$s" class="single-widget widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
	register_sidebar( array(
		'name'          => esc_html__( 'Footer Widget 4', 'exbico' ),
		'id'            => 'exbico_footer_4',
		'description'   => esc_html__( 'Add footer widget here.', 'exbico' ),
		'before_widget' => '<div id="%1$s" class="single-widget widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
}
add_action( 'widgets_init', 'exbico_widgets_init' );


function exbico_wpdocs_custom_excerpt_length( $length ) {
	if ( is_admin() ) return $length;
    $excerptlength = absint(get_theme_mod('exbico_post_excerpt',22));
    return $excerptlength;
}
add_filter( 'excerpt_length', 'exbico_wpdocs_custom_excerpt_length', 999 );


/**
 * Enqueue scripts and styles.
 */
function exbico_scripts() {
	wp_enqueue_style( 'google-font', 'https://fonts.googleapis.com/css2?family=Poppins:ital,wght@0,400;0,500;0,600;0,700;0,800;0,900;1,400;1,500;1,800;1,900&display=swap');
	wp_enqueue_style( 'animate', get_template_directory_uri() . '/resource/css/animate.css', array(), '4.4.1' );
	wp_enqueue_style( 'bootstrap', get_template_directory_uri() . '/resource/css/bootstrap.css', array(), '4.4.1' );
	wp_enqueue_style( 'font-awesome', get_template_directory_uri() . '/resource/css/font-awesome.css', array(), '4.4.1' );
	wp_enqueue_style( 'owl-carousel', get_template_directory_uri() . '/resource/css/owl.carousel.css', array(), '1.0.0' );
	wp_enqueue_style( 'normalize', get_template_directory_uri() . '/resource/css/normalize.css', array(), '1.0.0' );
	wp_enqueue_style( 'exbico-style', get_stylesheet_uri(), array(), EXBICO_S_VERSION );
	wp_enqueue_style( 'exbico-responsive', get_template_directory_uri() . '/resource/css/responsive.css', array(), '1.0.0' );
	
	wp_enqueue_script( 'bootstrap', get_template_directory_uri() . '/resource/js/bootstrap.js', array('jquery'), '4.4.1', true );
	wp_enqueue_script( 'exbico-easing', get_template_directory_uri() . '/resource/js/easing.js', array('jquery'), '4.4.1', true );
	wp_enqueue_script( 'counter-up', get_template_directory_uri() . '/resource/js/jquery.counterup.js', array('jquery'), '4.4.1', true );
	wp_enqueue_script( 'scrollup', get_template_directory_uri() . '/resource/js/jquery.scrollUp.js', array('jquery'), '4.4.1', true );
	wp_enqueue_script( 'exbico-keyboard-nav', get_template_directory_uri() . '/resource/js/keyboard-nav.min.js', array('jquery'), '1.0', true );
	wp_enqueue_script( 'popper', get_template_directory_uri() . '/resource/js/popper.js', array('jquery'), '1.0', true );
	wp_enqueue_script( 'waypoints', get_template_directory_uri() . '/resource/js/waypoints.js', array('jquery'), '1.0', true );
	wp_enqueue_script( 'wow-js', get_template_directory_uri() . '/resource/js/wow.js', array('jquery'), '1.0', true );
	wp_enqueue_script( 'owl-carousel', get_template_directory_uri() . '/resource/js/owl.carousel.js', array('jquery'), '1.6.0', true );

	wp_enqueue_script( 'navigation', get_template_directory_uri() . '/resource/js/navigation.js', array(), EXBICO_S_VERSION, true );
	wp_enqueue_script( 'exbico-skip-link-js', get_template_directory_uri() . '/resource/js/skip-link-focus-fix.js', array('jquery'), '1.0', true );
	wp_enqueue_script( 'exbico-main', get_template_directory_uri() . '/resource/js/main.js', array('jquery'), '1.0.0', true );	

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'exbico_scripts' );

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/includes/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/includes/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/includes/template-functions.php';

/**
 * Load TGM plugins for required plugins.
 */
require get_template_directory() . '/includes/tgm/required-plugins.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/includes/customizer.php';